Speciation
==========

Speciation in emiproc means splitting a substance in multiple sub=substances. 

This can be used for example to split NOx in NO and NO2 or to split 
the anthropogenic and biogenic part of a CO2.

.. autofunction:: emiproc.speciation.speciate

.. autofunction:: emiproc.speciation.merge_substances


Input/Output
^^^^^^^^^^^^

.. autofunction:: emiproc.speciation.read_speciation_table